<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl">
    <extra-po-header-po_revision_date>2010-08-28 14:36+0200</extra-po-header-po_revision_date>
    <extra-po-headers>MIME-Version,Content-Type,Content-Transfer-Encoding,Plural-Forms,X-Language,X-Qt-Contexts,Last-Translator,PO-Revision-Date,Project-Id-Version,Language-Team,X-Generator</extra-po-headers>
    <extra-po-header-x_generator>Lokalize 1.1</extra-po-header-x_generator>
    <extra-po-header-language_team>Slovenian &lt;lugos-slo@lugos.si&gt;</extra-po-header-language_team>
    <extra-po-header-project_id_version></extra-po-header-project_id_version>
    <extra-po-header_comment># Jure Repinc &lt;jlp@holodeck1.com&gt;, 2010.</extra-po-header_comment>
    <extra-po-header-last_translator>Jure Repinc &lt;jlp@holodeck1.com&gt;</extra-po-header-last_translator>
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation>Zunanjega programa ni moč zagnati.
</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Napaka pri registraciji datoteke z dokumentacijo »%1«: %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Napaka: %1</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Ni bilo moč registrirati datoteke z dokumentacijo
%1

Razlog:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Dokumentacija je bila uspešno registrirana.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Ni bilo moč od-registrirati datoteke z dokumentacijo
%1

Razlog:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Dokumentacija je bila uspešno odstranjena iz registrira.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Napaka pri branju datoteke zbirke »%1«: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Napaka pri ustvarjanju datoteke zbirke »%1«: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Ni moč naložiti gonilnika za podatkovno zbirko SQLite.</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Dodaj zaznamek</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Zaznamek:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Dodaj v mapo:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nova mapa</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Preimenuj mapo</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Nova mapa</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Brez naslova</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Untitled</source>
        <translation>Brez naslova</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Nameravate zbrisati mapo, pri čemer bo zbrisana&lt;br&gt;tudi njena vsebina. Ali res želite nadaljevati?</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Upravljanje zaznamkov ...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Dodaj zaznamek ...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Izbriši mapo</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Preimenuj mapo</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Prikaži zaznamek</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Prikaži zaznamek v novem zavihku</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Izbriši zaznamek</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Preimenuj zaznamek</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Upravljanje zaznamkov</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Išči:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Uvozi in ustvari varnostno kopijo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Uvozi ...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Izvozi ...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Datoteke (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Shrani datoteko</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Zaznamkov ni moč shraniti.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Nameravate zbrisati mapo, pri čemer bo zbrisana&lt;br&gt;tudi njena vsebina. Ali res želite nadaljevati?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Izbriši mapo</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Preimenuj mapo</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Prikaži zaznamek</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Prikaži zaznamek v novem zavihku</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Izbriši zaznamek</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Preimenuj zaznamek</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Meni z zaznamki</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>Zaznamki</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Add new page</source>
        <translation>Dodaj novo stran</translation>
    </message>
    <message>
        <source>Close current page</source>
        <translation>Zapri trenutno stran</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Natisni dokument</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>neznano</translation>
    </message>
    <message>
        <source>Add New Page</source>
        <translation>Dodaj novo stran</translation>
    </message>
    <message>
        <source>Close This Page</source>
        <translation>Zapri to stran</translation>
    </message>
    <message>
        <source>Close Other Pages</source>
        <translation>Zapri druge strani</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Dodaj zaznamek za to stran ...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Re-builds the full text search index (potentially slow).
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Uporaba: assistant [možnosti]

-collectionFile file       Namesto privzete datoteke zbirke
                           uporabi navedeno
-showUrl url               Prikaže dokument z URL-jem
-enableRemoteControl       Omogoča oddaljeni nadzor
-show podokno              Prikaže navedeno podokno,
                           ki je lahko »contents«, »index«,
                           »bookmarks« ali »search«.
-activate podokno          Aktivira navedeno podokno,
                           ki je lahko »contents«, »index«,
                           »bookmarks« ali »search».
-hide podokno              Skrije navedeno podokno,
                           ki je lahko »contents«, »index«
                           »bookmarks« ali »search«.
-register datoteka         Registrira navedeno datoteko s pomočjo
                           (.qch) v dani datoteki zbirke.
-unregister datoteka       Odregistrira navedeno datoteko s pomočjo
                           (.qch) iz dane datoteke zbirke.
-setCurrentFilter filter   Nastavi filter kot aktiven.
-remove-search-index       Odstrani kazalo za iskanje po celotnem besedilu.
-rebuild-search-index      Znova zgradi kazalo za iskanje po celotnem besedilu (lahko počasno).
-quiet                     Ne prikaže nobenega sporočila
                           napake ali stanja.
-help                      Prikaže to pomoč.
</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation>Neznana možnost: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Datoteka zbirke »%1« ne obstaja.</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Manjkajoča datoteka zbirke.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Neveljaven URL »%1«.</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>Manjkajoč URL.</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Neznan gradnik: %1</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Manjkajoč gradnik.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Datoteka s pomočjo za Qt »%1« ne obstaja.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Manjkajoča datoteka s pomočjo.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Manjkajoč argument filtra.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Opomba</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Odpri povezavo</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Odpri povezavo v novem zavihku</translation>
    </message>
</context>
<context>
    <name>ConversionWizard</name>
    <message>
        <source>Help Conversion Wizard</source>
        <translation>Čarovnik za pretvorbo pomoči</translation>
    </message>
    <message>
        <source>Converting %1...</source>
        <translation>Pretvarjanje %1 ...</translation>
    </message>
    <message>
        <source>Writing help collection file...</source>
        <translation>Zapisovanje datoteke z zbirko pomoči ...</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation>Opravljeno.</translation>
    </message>
</context>
<context>
    <name>FilesPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Files:</source>
        <translation>Datoteke:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Odstrani vse</translation>
    </message>
    <message>
        <source>Unreferenced Files</source>
        <translation>Nesklicevane datoteke</translation>
    </message>
    <message>
        <source>Remove files which are neither referenced by a keyword nor by the TOC.</source>
        <translation>Odstrani datoteke, na katere se ne sklicuje niti ključna beseda niti vsebinsko kazalo.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Warning:&lt;/b&gt; Be aware when removing images or stylesheets since those files are not directly referenced by the .adp or .dcf file.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Opozorilo:&lt;/b&gt; Pazite pri odstranjevanju slik ali slogovnih predlog, saj se nanje datoteke *.adp ali *.dcf ne sklicujejo neposredno.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>Dodaj ime filtra</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Ime filtra:</translation>
    </message>
</context>
<context>
    <name>FilterPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Filter attributes for current documentation (comma separated list):</source>
        <translation>Filtrirne lastnosti za trenutno dokumentacijo (seznam, ločen z vejicami):</translation>
    </message>
    <message>
        <source>Custom Filters</source>
        <translation>Filtri po meri</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Filter Settings</source>
        <translation>Nastavitve filtra</translation>
    </message>
    <message>
        <source>Specify the filter attributes for the documentation. If filter attributes are used, also define a custom filter for it. Both, the filter attributes and the custom filters are optional.</source>
        <translation>Določite filtrirne lastnosti za dokumentacijo. Če so uporabljene filtrirne lastnosti, določite tudi filter po meri zanje. Filtrirne lastnosti in filtri po meri niso obvezni.</translation>
    </message>
    <message>
        <source>Filter Name</source>
        <translation>Ime filtra</translation>
    </message>
    <message>
        <source>Filter Attributes</source>
        <translation>Filtrirne lastnosti</translation>
    </message>
    <message>
        <source>The custom filter &apos;%1&apos; is defined multiple times.</source>
        <translation>Filter po meri »%1« je določen večkrat.</translation>
    </message>
    <message>
        <source>The attributes for custom filter &apos;%1&apos; are defined multiple times.</source>
        <translation>Lastnosti za filer po meri »%1« so določene večkrat.</translation>
    </message>
    <message>
        <source>unfiltered</source>
        <comment>list of available documentation</comment>
        <translation>nefiltrirano</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Predhodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednje</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Loči velike in male črke</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Iskanje se nadaljuje na drugem koncu</translation>
    </message>
</context>
<context>
    <name>FinishPage</name>
    <message>
        <source>Converting File</source>
        <translation>Pretvarjanje datoteke</translation>
    </message>
    <message>
        <source>Creating the new Qt help files from the old ADP file.</source>
        <translation>Ustvarjanje novih datotek s pomočjo za Qt iz starih datotek ADP.</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Pisava</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>S&amp;istem pisanja</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Družina</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>&amp;Slog</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Velikost v točkah</translation>
    </message>
</context>
<context>
    <name>GeneralPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Namespace:</source>
        <translation>Imenski prostor:</translation>
    </message>
    <message>
        <source>Virtual Folder:</source>
        <translation>Navidezna mapa:</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Splošne nastavitve</translation>
    </message>
    <message>
        <source>Specify the namespace and the virtual folder for the documentation.</source>
        <translation>Določite imenski prostor in navidezno mapo za dokumentacijo.</translation>
    </message>
    <message>
        <source>Namespace Error</source>
        <translation>Napaka imenskega prostora</translation>
    </message>
    <message>
        <source>The namespace contains some invalid characters.</source>
        <translation>Imenski prostor vsebuje neveljavne znake.</translation>
    </message>
    <message>
        <source>Virtual Folder Error</source>
        <translation>Napaka navidezne mape</translation>
    </message>
    <message>
        <source>The virtual folder contains some invalid characters.</source>
        <translation>Navidezna mapa vsebuje neveljavne znake.</translation>
    </message>
</context>
<context>
    <name>HelpGenerator</name>
    <message>
        <source>Warning: %1</source>
        <translation>Opozorilo: %1</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;about:blank&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Napaka 404&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Strani ni bilo moč najti&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;»%1«&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Skopiraj &amp;povezavo do lokacije</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Odpri povezavo v novem zavihku	Ctrl+LGM</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Odpri povezavo v novem zavihku</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&lt;center&gt;&lt;b&gt;Wizard Assistant&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;Čarovniški pomočnik&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
</context>
<context>
    <name>IdentifierPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Create identifiers</source>
        <translation>Ustvari identifikatorje</translation>
    </message>
    <message>
        <source>Global prefix:</source>
        <translation>Globalna predpona:</translation>
    </message>
    <message>
        <source>Inherit prefix from file names</source>
        <translation>Predpono prevzemi iz imen datotek</translation>
    </message>
    <message>
        <source>Identifiers</source>
        <translation>Identifikatorji</translation>
    </message>
    <message>
        <source>This page allows you to create identifiers from the keywords found in the .adp or .dcf file.</source>
        <translation>Ta stran vam omogoča, da iz ključnih besed v datoteki *.adp ali *.dcf ustvarite identifikatorje.</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>&amp;Išči:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Odpri povezavo</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Odpri povezavo v novem zavihku</translation>
    </message>
</context>
<context>
    <name>InputPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation>Ime datoteke:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Input File</source>
        <translation>Vhodna datoteka</translation>
    </message>
    <message>
        <source>Specify the .adp or .dcf file you want to convert to the new Qt help project format and/or collection format.</source>
        <translation>Določite datoteko *.adp ali *.dcf, ki jo želite pretvoriti v novo obliko projekta pomoči za Qt in/ali zbirke.</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <source>Qt Help Files (*.adp *.dcf)</source>
        <translation>Datoteke s pomočjo za Qt (*.adp, *.dcf)</translation>
    </message>
    <message>
        <source>File Open Error</source>
        <translation>Napaka odpiranja datoteke</translation>
    </message>
    <message>
        <source>The specified file could not be opened!</source>
        <translation>Navedene datoteke ni bilo moč odpreti.</translation>
    </message>
    <message>
        <source>File Parsing Error</source>
        <translation>Napaka razčlenjevanja datoteke</translation>
    </message>
    <message>
        <source>Parsing error in line %1!</source>
        <translation>Napaka razčlenjevanja v vrstici %1.</translation>
    </message>
</context>
<context>
    <name>InstallDialog</name>
    <message>
        <source>Install Documentation</source>
        <translation>Namesti dokumentacijo</translation>
    </message>
    <message>
        <source>Available Documentation:</source>
        <translation>Razpoložljiva dokumentacija:</translation>
    </message>
    <message>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <source>Installation Path:</source>
        <translation>Namestitvena pot:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Downloading documentation info...</source>
        <translation>Prejemanje podatkov o dokumentaciji ...</translation>
    </message>
    <message>
        <source>Download canceled.</source>
        <translation>Prejemanje preklicano.</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation>Opravljeno.</translation>
    </message>
    <message>
        <source>The file %1 already exists. Do you want to overwrite it?</source>
        <translation>Datoteka %1 že obstaja. Ali jo želite nadomestiti?</translation>
    </message>
    <message>
        <source>Unable to save the file %1: %2.</source>
        <translation>Datoteke %1 ni moč shraniti: %2.</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Prejemanje %1 ...</translation>
    </message>
    <message>
        <source>Download failed: %1.</source>
        <translation>Prejemanje ni uspelo: %1.</translation>
    </message>
    <message>
        <source>Documentation info file is corrupt!</source>
        <translation>Datoteka s podatki o dokumentaciji je poškodovana.</translation>
    </message>
    <message>
        <source>Download failed: Downloaded file is corrupted.</source>
        <translation>Prejemanje ni uspelo. Prejeta datoteka je poškodovana.</translation>
    </message>
    <message>
        <source>Installing documentation %1...</source>
        <translation>Nameščanje dokumentacije %1 ...</translation>
    </message>
    <message>
        <source>Error while installing documentation:
%1</source>
        <translation>Napaka pri nameščanju dokumentacije:
%1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Kazalo</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Vsebina</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Zaznamki</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>iskanje dokumentacije za Qt ...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nov zavi&amp;hek</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>Nastavitve stra&amp;ni ...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Ogled tiskanja ...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Na&amp;tisni ...</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zapri zavihek</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Konča&amp;j</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Urejanje</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>S&amp;kopiraj izbrano besedilo</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>&amp;Najdi v besedilu ...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Najdi</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Najdi na&amp;slednje</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Najdi p&amp;rejšnje</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Nastavitve ...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Videz</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>Po&amp;večaj</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>Z&amp;manjšaj</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>&amp;Običajna velikost</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>Alt+K</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>Alt+Z</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>&amp;Pojdi</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Domov</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>Alt+Domov</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>Na&amp;zaj</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Naprej</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Uskladi s seznamom vsebine</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Uskladi</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Naslednja stran</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Desno</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Predhodna stran</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Levo</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Zaznamki</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoč</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>O ...</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Orodjarna za krmarjenje</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Povečava</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Pomanjšaj</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Orodjarne</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Orodjarna filtra</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Filtrirano po:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Naslovna vrstica</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Naslov:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Povezane postavke vsebine ni bilo moč najti.</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Različica %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Avtorske pravice © 2012 Digia Plc in/ali njene podružnice.&lt;/p&gt;&lt;p&gt;Prevedel: &lt;a href=&quot;mailto:jlp@holodeck1.com&quot;&gt;Jure Repinc&lt;/a&gt;, &lt;a href=&quot;http://www.lugos.si/&quot;&gt;LUGOS&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Posodabljanje kazala za iskanje</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Datoteke »%1« ni bilo moč registrirati: %2</translation>
    </message>
</context>
<context>
    <name>OutputPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Project file name:</source>
        <translation>Ime projektne datoteke:</translation>
    </message>
    <message>
        <source>Collection file name:</source>
        <translation>Ime datoteke zbirke:</translation>
    </message>
    <message>
        <source>Output File Names</source>
        <translation>Imena izhodnih datotek</translation>
    </message>
    <message>
        <source>Specify the file names for the output files.</source>
        <translation>Določite imena datotek za izhodne datoteke.</translation>
    </message>
    <message>
        <source>Convert...</source>
        <translation>Pretvori ...</translation>
    </message>
    <message>
        <source>Qt Help Project File</source>
        <translation>Projektna datoteka pomoči za Qt</translation>
    </message>
    <message>
        <source>Qt Help Collection Project File</source>
        <translation>Projektna datoteka zbirke pomoči za Qt</translation>
    </message>
    <message>
        <source>The specified file %1 already exist.

Do you want to remove it?</source>
        <translation>Navedena datoteka %1 že obstaja.

Ali jo želite odstraniti?</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
<context>
    <name>PathPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>File filters:</source>
        <translation>Datotečni filtri:</translation>
    </message>
    <message>
        <source>Documentation source file paths:</source>
        <translation>Poti z izvornimi datotekami za dokumentacijo:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Source File Paths</source>
        <translation>Poti izvornih datotek</translation>
    </message>
    <message>
        <source>Specify the paths where the sources files are located. By default, all files in those directories matched by the file filter will be included.</source>
        <translation>Določite poti do mest, kjer se nahajajo izvorne datoteke. Privzeto bodo vključene vse datoteke iz map, ki se ujemajo z datotečnim filtrom.</translation>
    </message>
    <message>
        <source>Source File Path</source>
        <translation>Pot izvorne datoteke</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>Dodaj dokumentacijo</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Stisnjene datoteke s pomočjo za Qt (*.qch)</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>Imenski prostor %1 je že registriran.</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>Navedena datoteka ni veljavna datoteka s pomočjo za Qt.</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>Odstrani dokumentacijo</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>Nekateri odprti dokumenti se sklicujejo na dokumentacijo, ki jo poskušate odstraniti. Odstranitev dokumentacije bo povzročila zaprtje teh dokumentov.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Uporabi nastavitve po meri</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Pisave</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Nastavitve pisav</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Brskalnik</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>Lastnosti:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentacija</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>Registrirana dokumentacija</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Dodaj ...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>Ob zagonu pomoči:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Prikaži mojo domačo stran</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Prikaži prazno stran</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Prikaži moje zavihke iz zadnje seje</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domača stran</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Trenutna stran</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Prazna stran</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Ponastavi na privzeto</translation>
    </message>
</context>
<context>
    <name>QCollectionGenerator</name>
    <message>
        <source>Unknown token at line %1.</source>
        <translation>Neznan žeton v vrstici %1.</translation>
    </message>
    <message>
        <source>Unknown token at line %1. Expected &quot;QtHelpCollectionProject&quot;.</source>
        <translation>Neznan žeton v vrstici %1. Pričakocan »QtHelpCollectionProject«.</translation>
    </message>
    <message>
        <source>Missing end tags.</source>
        <translation>Manjkajoče končne značke.</translation>
    </message>
    <message>
        <source>Missing input or output file for help file generation.</source>
        <translation>Manjkajoča vhodna ali izhodna datoteka za ustvarjanje datoteke s pomočjo.</translation>
    </message>
    <message>
        <source>Missing output file name.</source>
        <translation>Manjkajoče ime izhodne datoteke.</translation>
    </message>
    <message>
        <source>Qt Collection Generator version 1.0 (Qt %1)
</source>
        <translation>Qt Collection Generator različice 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>Missing collection config file.</source>
        <translation>Manjkajoča nastavitvena datoteka zbirke.</translation>
    </message>
    <message>
        <source>
Usage:

qcollectiongenerator &lt;collection-config-file&gt; [options]

  -o &lt;collection-file&gt;   Generates a collection file
                         called &lt;collection-file&gt;. If
                         this option is not specified
                         a default name will be used.
  -v                     Displays the version of
                         qcollectiongenerator.

</source>
        <translation>
Uporaba:

qcollectiongenerator &lt;nastavitvena-datoteka&gt; [možnosti]

  -o &lt;datoteka-zbirke&gt;   Ustvari datoteko zbirke z
                         imenom &lt;datoteka-zbirke&gt;. če
                         ta možnost ni uporabljena,
                         se uporabi privzeto ime.
  -v                     Prikaže različico za
                         qcollectiongenerator.

</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation>Ni bilo moč odpreti %1.
</translation>
    </message>
    <message>
        <source>Reading collection config file...
</source>
        <translation>Branje nastavitvene datoteke zbirke ...
</translation>
    </message>
    <message>
        <source>Collection config file error: %1
</source>
        <translation>Napaka nastavitvene datoteke zbirke: %1
</translation>
    </message>
    <message>
        <source>Generating help for %1...
</source>
        <translation>Ustvarjanje pomoči za %1 ...
</translation>
    </message>
    <message>
        <source>Creating collection file...
</source>
        <translation>Ustvarjanje datoteke zbirke ...
</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten.
</source>
        <translation>Datoteke %1 ni moč nadomestiti.
</translation>
    </message>
    <message>
        <source>Cannot open %1.
</source>
        <translation>Ni moč odpreti %1.
</translation>
    </message>
    <message>
        <source>Cannot open referenced image file %1.
</source>
        <translation>Ni moč odpreti sklicane slikovne datoteke %1.
</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Missing output file name.</source>
        <translation>Manjkajoče ime izhodne datoteke.</translation>
    </message>
    <message>
        <source>Qt Help Generator version 1.0 (Qt %1)
</source>
        <translation>Qt Help Generator različice 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>Missing Qt help project file.</source>
        <translation>Manjkajoča projektna datoteka pomoči za Qt.</translation>
    </message>
    <message>
        <source>
Usage:

qhelpgenerator &lt;help-project-file&gt; [options]

  -o &lt;compressed-file&gt;   Generates a Qt compressed help
                         file called &lt;compressed-file&gt;.
                         If this option is not specified
                         a default name will be used.
  -c                     Checks whether all links in HTML files
                         point to files in this help project.
  -v                     Displays the version of 
                         qhelpgenerator.

</source>
        <translation>
Uporaba:

qcollectiongenerator &lt;projektna-datoteka&gt; [možnosti]

  -o &lt;stisnjena-datoteka&gt;   Ustvari stisnjeno datoteko pomoči
                            za Qt, z imenom &lt;stisnjena-datoteka&gt;. če
                            ta možnost ni uporabljena,
                            se uporabi privzeto ime.
  -c                        Preveri, ali vse povezave v datotekah HTML
                            kažejo na datoteke v tem projektu pomoči.
  -v                        Prikaže različico za
                            qhelpgenerator

</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation>Ni bilo moč odpreti %1.
</translation>
    </message>
    <message>
        <source>Could not create output directory: %1
</source>
        <translation>Ni bilo moč ustvariti izhodne mape: %1
</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Razhroščevanje oddaljenega nadzora</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Prejet ukaz: %1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>S&amp;kopiraj</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Skopiraj &amp;povezavo do lokacije</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Odpri povezavo v novem zavihku</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Izberi vse</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Choose Topic</source>
        <translation>Izberite temo</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Teme</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Prikaži</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Izberite temo za &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
</context>
</TS>
